//////////////////////////////////////////////////////////////////////////
// define domains

domain='burble.dn42';
pdns_domain(domain);

//////////////////////////////////////////////////////////////////////////
// special records

D_EXTEND(
    domain,
    TXT('canary', "It's Alive!", TTL(1))
);

//////////////////////////////////////////////////////////////////////////
// services

// IPv4 service names
service('ns1',       'fd42:4242:2601:ac53::1',  '172.20.129.1');
service('dns',       'fd42:4242:2601:ac53::53', '172.20.129.2');
service('@',         'fd42:4242:2601:ac80::1',  '172.20.129.3');
service('grc',       'fd42:4242:2601:ac12::1',  '172.20.129.4');
service('pingable',  'fd42:4242:2601:ac05::1',  '172.20.129.5');
// 172.20.129.6 was wiki but not now used
service('rproxy',    'fd42:4242:2601:acf0::1',  '172.20.129.7');
service('whois',     'fd42:4242:2601:ac43::1',  '172.20.129.8');
// services 172.20.129.9 -> 172.20.129.31 are unassigned

// internal anycasts
service('rpki',           'fd42:4242:2601:ac10::1');
service('dns64',          'fd42:4242:2601:ac53::64'),
service('wiki.service',   'fd42:4242:2601:ac00::10:1'),
service('dn42regsrv',     'fd42:4242:2601:ac00::20:1');
service('dns-slave',      'fd42:4242:2601:ac00::53:1');
service('consul.service', 'fd42:4242:2601:acf0::10:1'),
service('vault.service',  'fd42:4242:2601:acf0::20:1'),
service('acme',           'fd42:4242:2601:acf0::30:1'),
service('minio',          'fd42:4242:2601:acf0::40:1'),
service('etcd',           'fd42:4242:2601:acf0::50:1'),

// proxied services
proxied('explorer');
proxied('ci');
proxied('glass');
proxied('lg');
proxied('wiki');
proxied('lounge');
proxied('nextcloud');
proxied('alertmanager');
proxied('monitor');
proxied('grafana');
proxied('consul');
proxied('vault');
proxied('paste');
proxied('tasks');
proxied('n8n');
proxied('wdev');
proxied('fusion');

// other service cnames
D_EXTEND(
    domain,

    // global service aliases
    CNAME('www',      'burble.dn42.'),
    CNAME('git',      'git.de-fra1.burble.dn42.'),

    // local service aliases
    CNAME('wiki.us',  'nginx.us-dal3.burble.dn42.'),
    CNAME('wiki.fr',  'nginx.de-fra1.burble.dn42.'),
    CNAME('wiki.sg',  'nginx.sg-sin2.burble.dn42.'),
    CNAME('wiki.ca',  'nginx.ca-bhs2.burble.dn42.'),    

    // host aliases
    CNAME('repo', 'repo.tier2.fr-rbx1.burble.dn42.'),

    // grc SSHFP
    SSHFP('grc', 4, 1, 'ff61153c18334e89df3b4b4e4696306eeb5ffe9c'),
    SSHFP('grc', 4, 2, 'c3a2470309cb1e6fba252231a6504a096ffd8b6f92442493f762e7512c515e76'),

    // dn42.dev mail
    MX('mail-dn42dev', 10, 'mail-dn42dev.tier2.de-fra1.burble.dn42.'),
    MX('mail-dn42dev', 10, 'mail-dn42dev.tier2.ca-bhs2.burble.dn42.'),

    // speedtest
    CNAME('speedtest.fr-rbx1', 'nginx.fr-rbx1.burble.dn42.'),
    CNAME('speedtest.ca-bhs2', 'nginx.ca-bhs2.burble.dn42.'),

    // etcd service discovery
    SRV('_etcd-server-ssl._tcp', 0, 0, 2380, 'etcd.tier2.fr-rbx1.burble.dn42.'),
    SRV('_etcd-server-ssl._tcp', 0, 0, 2380, 'etcd.tier2.uk-lon1.burble.dn42.'),
    SRV('_etcd-server-ssl._tcp', 0, 0, 2380, 'etcd.tier2.ca-bhs2.burble.dn42.'),
    SRV('_etcd-server-ssl._tcp', 0, 0, 2380, 'etcd.tier2.de-fra1.burble.dn42.'),
    SRV('_etcd-server-ssl._tcp', 0, 0, 2380, 'etcd.tier2.us-dal3.burble.dn42.'),    

    SRV('_etcd-client-ssl._tcp', 0, 0, 2379, 'etcd.burble.dn42.')
    
);

//////////////////////////////////////////////////////////////////////////
// hosts

// dmz special config
D_EXTEND(
    domain,

    AAAA('dmz.uk-lon1', '2a04:92c5:2:1::1'),
    AAAA('dmz.de-fra1', '2a0d:5941:1:17c::4e2a'),
    AAAA('dmz.fr-rbx1', '2001:41d0:8:6a47::1'),
    AAAA('dmz.ca-bhs2', '2607:5300:120:81a::1')
);

// main nodes

nodes.forEach(function(n) {
    var hex = (n[4] + 32).toString(16);
    var ip4 = (n[5] == 'undefined' ? undefined : n[5]);
    
    // main IP
    host(n[0],'fd42:4242:2601:'+hex+'::1', ip4);
    // tier2 IP
    host('tier2.'+n[0], 'fd42:4242:2601:'+hex+'02::1');

    // create dn42-xxx CNAME for dn42 nodes
    if (n[3] == 'true') {
        D_EXTEND(domain,CNAME('dn42-'+n[0], n[0]+'.burble.dn42.'));
    }
});

// containers and VMs

virtual.forEach(function(v) {
    host(v[0], v[1], v[2]);
});

//////////////////////////////////////////////////////////////////////////
// end of file

